Description
===========

|Build Status| |Coverage Status|

**yodel** (*the Swiss Army knife of your sound*) is an easy-to-use
python package for digital audio signal processing, analysis and
synthesis.

Changelog
=========

Version 0.1.1
-------------

-  Renaming the project to Yodel
-  Better packaging for PyPI

Version 0.1.0
-------------

-  First release of Damn!
-  Signal analysis module:

   -  Discrete Fourier Transform
   -  Fast Fourier Transform
   -  Analysis windows (Hanning, Hamming, Blackman)

-  Filtering module:

   -  Biquad filter

-  Utility modules for complex numbers and conversions

License
=======

The MIT License (MIT)

Copyright (c) 2014 Romain Clement

.. |Build Status| image:: https://travis-ci.org/rclement/yodel.svg?branch=develop
   :target: https://travis-ci.org/rclement/yodel
.. |Coverage Status| image:: https://coveralls.io/repos/rclement/yodel/badge.png?branch=develop
   :target: https://coveralls.io/r/rclement/yodel?branch=develop
